# simple_nlp_library
Simple NLP library

## installation
```
python3 -m pip install --upgrade simple_nlp_library
```

## usage
```python
from simple_nlp_library import preprocessing

tokens = preprocessing.retrieve_semantic_tokens('The quick brown fox jumps over the lazy dog')
print(tokens)
```
